@@ -28,7 +28,7 @@ class CouchbaseBackup:
     def _backup(self):
         self.args.append(self.tempdir)
         try:
-            result = subprocess.run(self.args, check=True)
+            result = subprocess.check_output(self.args)
             logging.info(result)
         except subprocess.CalledProcessError as e:
             logging.error('cant create backup')
